==> hbase-1.7.2-src.tar.gz: hbase-1.7.2/hbase-server/src/main/java/org/apache/hadoop/hbase/namequeues/BalancerDecisionDetails.java <==
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.namequeues;

import org.apache.commons.lang.builder.ToStringBuilder;
import org.apache.hadoop.hbase.classification.InterfaceAudience;
import org.apache.hadoop.hbase.client.BalancerDecision;

/**
 * Balancer decision details that would be passed on to ring buffer for history
 */
@InterfaceAudience.Private
public class BalancerDecisionDetails extends NamedQueuePayload {

  public static final int BALANCER_DECISION_EVENT = 1;

  private final BalancerDecision balancerDecision;

  public BalancerDecisionDetails(BalancerDecision balancerDecision) {
    super(BALANCER_DECISION_EVENT);
    this.balancerDecision = balancerDecision;
  }

  public BalancerDecision getBalancerDecision() {
    return balancerDecision;
  }

  @Override
  public String toString() {
    return new ToStringBuilder(this)
      .append("balancerDecision", balancerDecision)
      .toString();
  }
}

==> hbase-2.4.13-src.tar.gz: hbase-2.4.13/hbase-server/src/main/java/org/apache/hadoop/hbase/namequeues/BalancerDecisionDetails.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.namequeues;

import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.hadoop.hbase.client.BalancerDecision;
import org.apache.yetus.audience.InterfaceAudience;

/**
 * Balancer decision details that would be passed on to ring buffer for history
 */
@InterfaceAudience.Private
public class BalancerDecisionDetails extends NamedQueuePayload {

  public static final int BALANCER_DECISION_EVENT = 1;

  private final BalancerDecision balancerDecision;

  public BalancerDecisionDetails(BalancerDecision balancerDecision) {
    super(BALANCER_DECISION_EVENT);
    this.balancerDecision = balancerDecision;
  }

  public BalancerDecision getBalancerDecision() {
    return balancerDecision;
  }

  @Override
  public String toString() {
    return new ToStringBuilder(this).append("balancerDecision", balancerDecision).toString();
  }
}
